;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x96b7f3e284f9250ddd2bfb46d4405d0e . "./code.cg2js/cg-acache.fasl")
(#xc5aae4d93d5a47ad8356ceb672986f9a . "./code.cg2js/cg-base.fasl")
(#xbc9d11ebaf5db748bbe22dcba7fcc3b7 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x652ec731089c3e2aeae651bef21c0e5d . "./code.cg2js/cg-bitmap-pane.fasl")
(#x034b68369e0e16cf2be1bc1a95885c86 . "./code.cg2js/cg-bitmap-stream.fasl")
(#xe9a68f4fc99b59ab9b91ad12da55cf55 . "./code.cg2js/cg-button.fasl")
(#xdd6f6687708106697aadd8f0a0e999c9 . "./code.cg2js/cg-calendar.fasl")
(#x9cab0f11d684de71feeecdf3c613d4f8 . "./code.cg2js/cg-caret.fasl")
(#x579d70f0881f99919a099784d150a5d6 . "./code.cg2js/cg-chart-or-plot.fasl")
(#xdecef42f6ccd7149e956ea8f81360e1c . "./code.cg2js/cg-chart-widget.fasl")
(#x3687e50ad9ee731b11c6ce99e476514f . "./code.cg2js/cg-check-box.fasl")
(#x24858127d11257a88fe04cb92e61d95f . "./code.cg2js/cg-choice-list.fasl")
(#x88f4114becf4086da05b34cfd88bcd14 . "./code.cg2js/cg-choose-printer.fasl")
(#x750e97a3b1e010e0f3a7943ebd039fc1 . "./code.cg2js/cg-class-grid.fasl")
(#xc7923ea7370829d4ae619ed90a6de1e3 . "./code.cg2js/cg-class-slot-grid.fasl")
(#xaae6931aae968e2afae022e796488c34 . "./code.cg2js/cg-class-support.fasl")
(#x36265326e2f1e8c0f6dca2350fe5048e . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x27d6f931a97f6bd5756fa36003f22d3d . "./code.cg2js/cg-clipboard-stack.fasl")
(#x5f1896424511d20ceafcfe0883226326 . "./code.cg2js/cg-clipboard.fasl")
(#x3880e07249b53fcd7694774f7e760e3d . "./code.cg2js/cg-color-dialog.fasl")
(#xc56097d56c0e55455c8f331d09e928eb . "./code.cg2js/cg-combo-box.fasl")
(#xe5a4e728264fe081e63bc0b77317098d . "./code.cg2js/cg-common-control.fasl")
(#x0dd178d0e8d980b9252cce8b7c7ea6f2 . "./code.cg2js/cg-comtab.fasl")
(#xb87abd249e8258c75ee5b669d9ccd187 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xfc871e57468b512da0dddb55fa44220d . "./code.cg2js/cg-curve.fasl")
(#xd739a4b81fb8b66e9f272dc5b69b21a0 . "./code.cg2js/cg-dde-utils.fasl")
(#xc82b2c20acdbab90e5a8225a8dbaa1fe . "./code.cg2js/cg-dev.fasl")
(#x3f37baa5029d1965b6036b37318ea0ba . "./code.cg2js/cg-dialog-item.fasl")
(#xa5159caf6bba3663bdee3561783326b6 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#xd0f9e85516f8b053f4a9e01c9d2ca766 . "./code.cg2js/cg-directory-dialog.fasl")
(#x3d6ad1c98f9c976fa2865dacf56897cb . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#xdf4bab40c25edf74135d215c25173f58 . "./code.cg2js/cg-drag-and-drop.fasl")
(#x933a9805be5c2d48e1f5f0fca7cfc0c4 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x0736a22915fb698a13d2d87fa314fcb0 . "./code.cg2js/cg-drawable.fasl")
(#x5a18e042e2f0595cf1ca32192a91763f . "./code.cg2js/cg-dropping-outline.fasl")
(#x9402236b6f075d4b21919ea00a77a511 . "./code.cg2js/cg-edit-in-place.fasl")
(#x3e81363406425f7eaa320b4c2c30f6c3 . "./code.cg2js/cg-editable-text.fasl")
(#x8a88f0b7d693e417c822781081bea89a . "./code.cg2js/cg-file-dialog.fasl")
(#x961efcb13426ec5fd69378d255fa095b . "./code.cg2js/cg-fill-texture.fasl")
(#x70581cfc68d3f19fe193431ef2f0d93d . "./code.cg2js/cg-find-string-dialog.fasl")
(#x56085739651ec01bc747180f5dacd895 . "./code.cg2js/cg-font-dialog.fasl")
(#x178ce27ce46ca1bebdea8f4b710f9630 . "./code.cg2js/cg-gesture-emulation.fasl")
(#x177dba155ef57c8de7dbb3d136be121e . "./code.cg2js/cg-get-pixmap.fasl")
(#x4d385711e1b7e2a7e625bbd511b326b2 . "./code.cg2js/cg-get-position.fasl")
(#x193806b43003f20a75bbf123ccb2fd9e . "./code.cg2js/cg-graphics-context.fasl")
(#xab8668460d2eaa91397a057cb4256829 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x3307165415b760024cd2b1212b546aa0 . "./code.cg2js/cg-grid-widget.fasl")
(#x0c95541483bcff3add0481d898d015b9 . "./code.cg2js/cg-group-box.fasl")
(#x28fb56b506abc0bc3f356ede481ee43e . "./code.cg2js/cg-header-control.fasl")
(#x9292e7f7664ddb56a3f42717136570be . "./code.cg2js/cg-hotspot.fasl")
(#x50320a5aa320388105050a0a85c2d0c9 . "./code.cg2js/cg-html-dialog.fasl")
(#x5640426f0034138184c87ffbea08c142 . "./code.cg2js/cg-html-widget.fasl")
(#x96d0fe99a4301416517c07d2a5a11c3e . "./code.cg2js/cg-icon-pixmap.fasl")
(#x486a3f2434aae325360eef3761e47fd1 . "./code.cg2js/cg-icon.fasl")
(#xc0f0e0ba0090666c3b1f7d88700baba7 . "./code.cg2js/cg-ie.fasl")
(#xa1e5ae2e44bccc7ec8f7a062999f2702 . "./code.cg2js/cg-intersect-posbox.fasl")
(#xddf693e062f8406572728dd95a629267 . "./code.cg2js/cg-intersect.fasl")
(#xfe1da3025940b00a94df670cf8e58ec7 . "./code.cg2js/cg-item-list.fasl")
(#x80e2068e3ae858d6d8d513c043ecdab4 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x9ada7880898a17875032a2804f1b8920 . "./code.cg2js/cg-lamp.fasl")
(#xeb072ef10d9c360b428a7faf708c5801 . "./code.cg2js/cg-layout.fasl")
(#x240dda5467a90acabdf64b1229d570bb . "./code.cg2js/cg-lettered-menu.fasl")
(#x2c1daedcf9391e71b1dcdc061e7c8158 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#xe8706c61ab177005ed0839da4388d70e . "./code.cg2js/cg-lisp-text.fasl")
(#xa5808802178ab85a3c7cc4e56b18f209 . "./code.cg2js/cg-lisp-widget.fasl")
(#x1556ec36bbcfaa6685ab44fb2df91e35 . "./code.cg2js/cg-list-view.fasl")
(#x1aa0b4781e0cf9b8c0a5bd941014118c . "./code.cg2js/cg-mci.fasl")
(#xec5e999430d41a16aede582e0addaf89 . "./code.cg2js/cg-menu-tooltip.fasl")
(#xb870088cb02cf64697b958fb22c8d6d5 . "./code.cg2js/cg-menu.fasl")
(#xa4c20f9d477f3d7428467d5b3f7267a5 . "./code.cg2js/cg-message-dialog.fasl")
(#x634468755bdd608720b82a3a717a741d . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x565dc8ccdb86c5a04cf4c03c75ec4fec . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#xd04e1854c325f357f7ab15d17d25a650 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x6510a660751d568a8a387085583890d5 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x8b9f876b49e957e23ffb8ed7565babff . "./code.cg2js/cg-multi-picture-button.fasl")
(#x9fb80916e5d31932da2e87297e225041 . "./code.cg2js/cg-nodes.fasl")
(#xfb58b89a05aa488a0eae56cc3f75d07c . "./code.cg2js/cg-object-editor-layout.fasl")
(#x5afbb42069e1b27250f01f532033fa1e . "./code.cg2js/cg-object-editor.fasl")
(#xd2a7fd4867377bd1490b921bd652e56a . "./code.cg2js/cg-ocx.fasl")
(#x9263c397f65877031cf204d539748dbd . "./code.cg2js/cg-os-widget.fasl")
(#x0427d5d6594808df57b28609d29645f0 . "./code.cg2js/cg-os-window.fasl")
(#x4b1ed07e9a78474f7e78ed283ab47819 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x98f00250db6cba1572159507179f2f10 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x9049ee24eb359b6c23410c212c845de6 . "./code.cg2js/cg-outline.fasl")
(#xe4fa9c2bc8f1427bcf6e3de41742cf54 . "./code.cg2js/cg-palette.fasl")
(#xa15c335217f225dbff6165da999e64e5 . "./code.cg2js/cg-paren-matching.fasl")
(#xe4de465bfe3250da80e0916b5a631c30 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x588226622f3d56671543f3ec6fa096e6 . "./code.cg2js/cg-picture-widget.fasl")
(#x79090b705716fdcb71a40fb1148a9832 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xfd61610c6b3555a8a9a705a715451edc . "./code.cg2js/cg-pixmap-printing.fasl")
(#x500b58ca24c575095d59d2002ed2ad67 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#xa8793d7192321ffed3979a1f9ceb484e . "./code.cg2js/cg-pixmap-widget.fasl")
(#x88a00d17e5be63bb5f36476a57074257 . "./code.cg2js/cg-pixmap.fasl")
(#xf824f96d0b67ef48d2a6bc788443aae9 . "./code.cg2js/cg-player.fasl")
(#xaa7ed6563239365558aea78fe3e295da . "./code.cg2js/cg-plot-widget.fasl")
(#x14d6d1dddce19c93ca6c936d78c75a27 . "./code.cg2js/cg-printing.fasl")
(#x5b3e055482fb48138b19717a704ffb27 . "./code.cg2js/cg-progress-indicator.fasl")
(#xb237d2444db3090c20c37934e365d92d . "./code.cg2js/cg-project-window.fasl")
(#x39febb80c2767c9c4d6d78a54e86577a . "./code.cg2js/cg-property.fasl")
(#xb701498b359088ff99a4681701a638af . "./code.cg2js/cg-radio-button.fasl")
(#x6730ad76d4c8f8e984248585c4564e7e . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#xb39cdb1fb3eb5fd3696530ce2bbff49e . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#xd6ab70032528cdf5efc6867aeb7e7cf3 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#xdbe11401c47d2e1b7e3edaf00519695c . "./code.cg2js/cg-rich-edit.fasl")
(#x8c85cfcf70e674b38eb77e2fd9160057 . "./code.cg2js/cg-sample-file-menu.fasl")
(#xa593022d8798d7290c5c4b0046802ffc . "./code.cg2js/cg-scaling-stream.fasl")
(#x18e4ddc68e5f384bc314381280fd1ff3 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x34ebe911cc895f2001fc610cdfd6ce7a . "./code.cg2js/cg-scroll-bar.fasl")
(#x842da337eabedbcd3df842716beef8cf . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x473185393fe3eb47c78824c60556081c . "./code.cg2js/cg-selected-object.fasl")
(#xf9af6fc4a2adb303b861dc388845ea42 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x1714f677e445620b104dc72a80db946e . "./code.cg2js/cg-split-bar.fasl")
(#x3bf01865e567a9878a31ab395fbf21ac . "./code.cg2js/cg-static-text.fasl")
(#x65fab9852bf45e433cb527638f55b881 . "./code.cg2js/cg-status-bar.fasl")
(#x164f389b4f5818accf5c642da9f1c0cd . "./code.cg2js/cg-string-dialog.fasl")
(#xa20e1f42b1eaff27724d45ddc2dc928c . "./code.cg2js/cg-tab-control.fasl")
(#xa4b152443f969ffa078a886e4a255633 . "./code.cg2js/cg-template-string.fasl")
(#x3b8eb2265999f6726b954643bf48f73e . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x92e479b09f50ed22562d982bb687dbb8 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#xb749efecf3bd7915e965c7951df6d0ec . "./code.cg2js/cg-text-edit-pane.fasl")
(#xbade0c2f8c682744da5962a4b1ccde6f . "./code.cg2js/cg-text-or-combo.fasl")
(#xacd8cfe29c11dc05658ef6f17b6321a2 . "./code.cg2js/cg-text-widget.fasl")
(#x1ae7ece01f7ca7ecbe25161be0fd34e1 . "./code.cg2js/cg-timer.fasl")
(#xd60bcd1fa65bcce80b4db5893a9f259a . "./code.cg2js/cg-toggling-widget.fasl")
(#x1c0e3b97fc242a8833bbe59b5c69a360 . "./code.cg2js/cg-toolbar.fasl")
(#x15056f65afa37ec53febab06d8e80528 . "./code.cg2js/cg-tooltip.fasl")
(#xcc669eaada1af2751ed00fd2052a576e . "./code.cg2js/cg-touch.fasl")
(#x09f8c0b237431d5fb4494754f7d8c2d8 . "./code.cg2js/cg-trackbar.fasl")
(#xd4b9228bedb9d25d50b3d70adf141abc . "./code.cg2js/cg-tray.fasl")
(#xe35ba01576ff0f82e04122893c8072bf . "./code.cg2js/cg-up-down-control.fasl")
(#x6039ed388f09e95ddd3008339910d792 . "./code.cg2js/cg-utility-dialog.fasl")
(#xc278664c7d60131c2742a9b87d314d2b . "./code.cg2js/cg-web-browser-dde.fasl")
(#x82431060a42567fb6191352406493359 . "./code.cg2js/cg-web-browser.fasl")
(#xe3ac374f54abbefd2b2ff05b406e90d2 . "./code.cg2js/cg-wrap-string.fasl")
(#x5367730d89f6bf649264ade893975f29 . "./code.cg2js/cg-yes-no-list.fasl")
(#x10fe7d3891dd8e361213d0daae8b0cd9 . "./code.cg2js/cg.fasl")
(#x635050131f6317786e4fb1dbe744c1c6 . "./code.cg2js/cg-yes-no-string.fasl")
(#xf98f11319ccdb2e0947d5669e5e9a883 . "./code.idejs/ide-acache.fasl")
(#x33c7eda28fabf386735885ed822bd315 . "./code.idejs/ide-apropos.fasl")
(#xf6e8b213978e007807cac317b75fec65 . "./code.idejs/ide-base.fasl")
(#x2550654edff28f063774db8ecafc7ba0 . "./code.idejs/ide-class-browser.fasl")
(#x5e285b4bcf3ee2480f00b1aea54deee7 . "./code.idejs/ide-class-grapher.fasl")
(#x65d968e0d1b87b6a08c3af8c158c7472 . "./code.idejs/ide-clipboard.fasl")
(#xb6d096cdec213a22975ab2e08c75b44f . "./code.idejs/ide-dev.fasl")
(#x51089970e8c24796190335bf11a32854 . "./code.idejs/ide-editor.fasl")
(#xb590e502647bd2c294073b7592223649 . "./code.idejs/ide-find-definitions.fasl")
(#xf8ad5ca5e2b65e1093e2d0691959753b . "./code.idejs/ide-find-in-files.fasl")
(#x54b7008babc7cb62fe4ebb05085f5ef9 . "./code.idejs/ide-form.fasl")
(#x28075f31ff816e5571e5a3a76df32e3e . "./code.idejs/ide-grapher.fasl")
(#xeb0ba6c4c0e3e9c1b2995c1fa150cad7 . "./code.idejs/ide-inspector.fasl")
(#xe4800425c6a95e5455c581832023145b . "./code.idejs/ide-intro.fasl")
(#x597392f360cfe506519627b525167b35 . "./code.idejs/ide-keyshort.fasl")
(#xb0203914731930026e93b2b8489b8190 . "./code.idejs/ide-navigator.fasl")
(#x1290168c2bd4e0235c2289c806036274 . "./code.idejs/ide-package-list.fasl")
(#xc5bb355095aefbdf0acd62e42e95d993 . "./code.idejs/ide-patch-dialog.fasl")
(#x4e15bd55c750fdbc0d3c3ba48e966431 . "./code.idejs/ide-process-browser.fasl")
(#x1f16af55d8a862c74dac8f1b1743b3b6 . "./code.idejs/ide-project.fasl")
(#xc1b288f7e8575efda49fa343d7115003 . "./code.idejs/ide-trace.fasl")
(#xcd29fe9517720f05a828373bb92348ae . "./code.idejs/ide-window-list.fasl")
(#x24e210204b506caf502fe1dcab08cafc . "./code.idejs/ide.fasl")
(#xf954c7d1d43ea0e0cec9ada7b7316935 . "./cgjs.html")
(#x55fea08d92e113f5a8381c271febbc9e . "./ssl-not-found.html")
(#x4e1b21622d7d9cc4e6fc09c7875f8430 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js" "code.idejs"))
    (format s "
(let ((path (make-pathname
             :host \"sys\"
             :directory '(:relative \"~a\")
	     :type \"fasl\"
	     )))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
